Coverage for modules/box__bizhelp/people/models.py: 100%

# Coverage for modules/box__bizhelp/people/models.py : 100%

## 18 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from init import db

2

3

4 class People(db.Model):

5 __tablename__ = "people"

6 id = db.Column(db.Integer, primary_key=True)

7 name = db.Column(db.String(100))

8 phone = db.Column(db.Integer)

9 mobile = db.Column(db.Integer)

10 email = db.Column(db.String(100))

11 facebook = db.Column(db.String(128))

12 twitter = db.Column(db.String(128))

13 linkedin = db.Column(db.String(128))

14 age = db.Column(db.Integer)

15 birthday = db.Column(db.String(100))

16 notes = db.Column(db.String(100))

17 is_manufacturer = db.Column(db.Boolean)

18 manufacturer_name = db.Column(db.String(100))

19 manufacturer_phone = db.Column(db.Integer)

20 manufacturer_address = db.Column(db.String(200))